OC.L10N.register(
    "viewer",
    {
    "Viewer" : "查看器",
    "Simple file viewer with slideshow for media" : "带媒体幻灯片的简单文件查看器",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "像电影一样展出您最新的假日照片和视频，直接在您的Nextcloud中浏览您最新的小说，借助您收藏文件的直接预览选择您专辑最佳的GIF，还有更多！",
    "Error loading {name}" : "加载 {name} 出错",
    "Your browser does not support the video tag." : "您的浏览器不支持视频标签。",
    "Open sidebar" : "打开侧边栏",
    "View" : "查看",
    "Share" : "共享"
},
"nplurals=1; plural=0;");
